==> haskell-dns-2.0.13-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.13
id: dns-2.0.13-FBR6qWqMTjUJPcc0KNxxCK
key: dns-2.0.13-FBR6qWqMTjUJPcc0KNxxCK
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
indefinite: False
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode
    Network.DNS.Lookup Network.DNS.Resolver Network.DNS.Types
    Network.DNS.Utils
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
abi: 3f5cd143d5e2336e2d816d982571f8e1
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/dns-2.0.13
library-dirs: /usr/lib/ghc-8.2.1/site-local/dns-2.0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/dns-2.0.13
hs-libraries: HSdns-2.0.13-FBR6qWqMTjUJPcc0KNxxCK
depends:
    base-4.10.0.0 attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    binary-0.8.5.1 bytestring-0.10.8.2
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK containers-0.5.10.2
    iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=08dd59974100c688bef2cfbf42e32e82
             binary-0.8.5.1=230c80b11ae3b1af831989b945ccdad4
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=bb78905b1378fcce46c05f1a905b300f
             conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK=63f38efa68cdbec8ffcaa63338d65c64
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am=df6c301c27b8ee75fd2d78b106528925
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=5531911f09693672654e6de645ce55e7
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=ef2cd2ee3956583f4f4dc001b18e6763
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=4de0c0628e95d26e613f423e1634f42a
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2ffddbfcc20d0db652f15951a99e02a7
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-2.0.13-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 2.0.13
id: dns-2.0.13-GIa0TNv3LcF49pGaGIMF0e
key: dns-2.0.13-GIa0TNv3LcF49pGaGIMF0e
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
indefinite: False
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode
    Network.DNS.Lookup Network.DNS.Resolver Network.DNS.Types
    Network.DNS.Utils
hidden-modules: Network.DNS.Internal Network.DNS.StateBinary
abi: f8e2dba19db6625e3113272aace6c205
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/dns-2.0.13
library-dirs: /usr/lib/ghc-8.2.1/site-local/dns-2.0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/dns-2.0.13
hs-libraries: HSdns-2.0.13-GIa0TNv3LcF49pGaGIMF0e
depends:
    base-4.10.0.0 attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    binary-0.8.5.1 bytestring-0.10.8.2
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.2.0-DSsj91zKB0UtOeZqteiA7 containers-0.5.10.2
    iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=08dd59974100c688bef2cfbf42e32e82
             binary-0.8.5.1=230c80b11ae3b1af831989b945ccdad4
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=bb78905b1378fcce46c05f1a905b300f
             conduit-extra-1.2.0-DSsj91zKB0UtOeZqteiA7=ca8b2ce8f761518ff184daa7d429ff43
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             iproute-1.7.1-IiB4a9W7GIo1P3kukLO5am=df6c301c27b8ee75fd2d78b106528925
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=5531911f09693672654e6de645ce55e7
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=ef2cd2ee3956583f4f4dc001b18e6763
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=4de0c0628e95d26e613f423e1634f42a
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2ffddbfcc20d0db652f15951a99e02a7
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
